Skip to main contentModule modules
Source - ModuleIter
- An iterator over the variants of Self
- Module
- await_module
- Blocks execution until the remaining cooldown of the module expires.
- force_field
- Activates a force field that grants temporary invincibility to the robot.
- gps
- Retrieves the absolute position (
x, y) of the robot from the center of the map using GPS. - laser
- Sends a laser scan at a specified angle to detect an object within the
robot’s line of sight.
- mine
- Drops a mine that activates after a short duration.
- radar
- Initiates a radar pulse to detect the closest enemy robot and retrieves the
position and distance relative to your robot.
- repair
- Repairs the specified robot component, restoring it to a significantly
healthier state.
- scan
- Initiates a 360-degree scan to detect nearby objects around the robot within a specified range.
- scan_for_bot
- Scans for the average position of the components of an enemy bot, if any are found.
- status
- Retrieves the status of a specific module.
- teleport
- DEPRECATED Teleports the robot to the specified coordinates (x, y) relative
to the robot within the game environment.
- thrust
- Activates a thruster to swiftly move the robot a short distance in the
specified global angle.